#include <WiFi.h>
#include <ThingSpeak.h>
#include <OneWire.h>
#include <DallasTemperature.h>

// Wi-Fi credentials
const char* ssid = "Redmi"; //  Wi-Fi SSID
const char* password = "prachi1234"; //  Wi-Fi Password

// ThingSpeak credentials
unsigned long channelID = 2674177; //ThingSpeak Channel ID
const char* apiKey = "LNI242V354FPYNQR"; //ThingSpeak API Key

// Pin definitions
#define TEMP_SENSOR_PIN 10
#define SOIL_MOISTURE_PIN 2 // Sensor pin for soil moisture sensor

// Setup OneWire and DallasTemperature
OneWire oneWire(TEMP_SENSOR_PIN);
DallasTemperature sensors(&oneWire);

//  WiFiClient object
WiFiClient client;

// Variables to hold sensor readings
float temperature;
int soilMoisture;

// Function to read soil moisture
int readSoilMoisture() {
    int moistureValue = analogRead(SOIL_MOISTURE_PIN);
    return moistureValue;
}

void setup() {
    Serial.begin(115200);
    
    // Initialize Wi-Fi
    WiFi.begin(ssid, password);
    while (WiFi.status() != WL_CONNECTED) {
        delay(1000);
        Serial.println("Connecting to WiFi...");
    }
    Serial.println("Connected to WiFi");

    // Initialize ThingSpeak
    ThingSpeak.begin(client);

    // Initialize temperature sensor
    sensors.begin();
}

void loop() {
    // Read temperature
    sensors.requestTemperatures();
    temperature = sensors.getTempCByIndex(0); // Get temperature in Celsius
    soilMoisture = readSoilMoisture(); // Read soil moisture

    // Print values to Serial Monitor
    Serial.print("Temperature: ");
    Serial.print(temperature);
    Serial.print(" °C, Soil Moisture: ");
    Serial.println(soilMoisture);

    // Update ThingSpeak with new data
    ThingSpeak.setField(1, soilMoisture); // Update field 1 with soil moisture value
    ThingSpeak.setField(2, temperature); // Update field 2 with temperature value

    // Write to ThingSpeak
    int result = ThingSpeak.writeFields(channelID, apiKey);
    if (result == 200) {
        Serial.println("Data updated successfully.");
    } else {
        Serial.print("Failed to update data. Error code: ");
        Serial.println(result);
    }

    // Wait for 15 seconds before sending the next update
    delay(15000);
}
